@@ -968,6 +968,9 @@ class CodeExecutor:
                 elif "cancelled" in result:
                     error_description = "Execution was cancelled by the system"
             
+            # Save the execution result (extracted data) before it gets overwritten
+            extracted_data = result
+            
             # Format the response according to the specified structure
             response = {
                 "codeOutput": result,
@@ -1009,11 +1012,11 @@ class CodeExecutor:
                 
                 # Use QoS level 1 for publishing to ensure at-least-once delivery
                 try:
-                    result = self.client.publish(response_topic, response_json, qos=1)
-                    if result.rc == mqtt.MQTT_ERR_SUCCESS:
-                        logger.debug(f"Successfully published result (ID: {result.mid})")
+                    mqtt_result = self.client.publish(response_topic, response_json, qos=1)
+                    if mqtt_result.rc == mqtt.MQTT_ERR_SUCCESS:
+                        logger.debug(f"Successfully published result (ID: {mqtt_result.mid})")
                     else:
-                        logger.error(f"Failed to publish result: MQTT error code {result.rc}")
+                        logger.error(f"Failed to publish result: MQTT error code {mqtt_result.rc}")
                 except Exception as e:
                     logger.error(f"Exception during publish: {str(e)}")
             else:
@@ -1028,8 +1031,10 @@ class CodeExecutor:
                     group = payload.get("group")
                     
                     # Schedule audit logging in background to not block
-                    asyncio.create_task(
-                        asyncio.get_event_loop().run_in_executor(
+                    # run_in_executor returns a Future, use ensure_future instead of create_task
+                    loop = asyncio.get_event_loop()
+                    asyncio.ensure_future(
+                        loop.run_in_executor(
                             None,  # Use default executor
                             self.audit_logger.log_execution,
                             query,
@@ -1037,14 +1042,15 @@ class CodeExecutor:
                             user,
                             status,
                             group,
-                            result if result else None,
+                            self.project_id,
+                            extracted_data if extracted_data else None,
                             error_description
                         )
                     )
                 except Exception as audit_error:
                     # Don't let audit logging failures affect execution
                     logger.error(f"Failed to schedule audit log: {audit_error}")
-                
+        
         except Exception as e:
             # Get total processing time regardless of errors
             total_time = time.time() - start_time
@@ -1073,11 +1079,11 @@ class CodeExecutor:
                     self.message_published_topics.add(response_topic)
                     
                     # Use QoS level 1 for publishing error responses
-                    result = self.client.publish(response_topic, json.dumps(error_response), qos=1)
-                    if result.rc == mqtt.MQTT_ERR_SUCCESS:
-                        logger.debug(f"Published error response (ID: {result.mid})")
+                    mqtt_error_result = self.client.publish(response_topic, json.dumps(error_response), qos=1)
+                    if mqtt_error_result.rc == mqtt.MQTT_ERR_SUCCESS:
+                        logger.debug(f"Published error response (ID: {mqtt_error_result.mid})")
                     else:
-                        logger.error(f"Failed to publish error response: MQTT error code {result.rc}")
+                        logger.error(f"Failed to publish error response: MQTT error code {mqtt_error_result.rc}")
                 except Exception as publish_error:
                     logger.error(f"Failed to publish error response: {str(publish_error)}")
                     logger.error(f"Exception traceback: {traceback.format_exc()}")
