@@ -6,7 +6,7 @@ import bcrypt
 import secrets
 import string
 from datetime import datetime, timedelta
-from typing import Optional, Dict, Any
+from typing import Optional, Dict, Any, List
 import logging
 import requests
 
@@ -20,20 +20,24 @@ class AuthManager:
     MAX_RESET_ATTEMPTS = 3
     RESET_ATTEMPT_WINDOW_MINUTES = 15
     
-    def __init__(self, db_path: str, account_service_url: str, project_id: str, api_key: str):
+    def __init__(self, db_path: str, account_service_url: str, project_id: str, api_key: str, 
+                 managed_projects: Optional[List[Dict[str, str]]] = None):
         """
         Initialize authentication manager.
         
         Args:
             db_path: Path to SQLite database for user credentials
             account_service_url: Base URL for account service API
-            project_id: Project ID for account service
-            api_key: API key for account service
+            project_id: Primary project ID for account service
+            api_key: API key for primary project
+            managed_projects: List of all managed projects (for multi-project password reset)
+                             Format: [{'project_id': 'proj1', 'api_key': 'key1'}, ...]
         """
         self.db_path = db_path
         self.account_service_url = account_service_url
         self.project_id = project_id
         self.api_key = api_key
+        self.managed_projects = managed_projects or [{'project_id': project_id, 'api_key': api_key}]
         
         self._init_database()
         self._ensure_default_admin()
@@ -283,29 +287,44 @@ class AuthManager:
             
             conn.commit()
         
-        # Send code to account service
-        try:
-            response = requests.post(
-                f"{self.account_service_url}/api/v1/service/broker/send-reset-code",
-                params={
-                    'projectId': self.project_id,
-                    'code': code
-                },
-                headers={
-                    'X-API-Key': self.api_key
-                },
-                timeout=10
-            )
-            
-            if response.status_code == 200:
-                logger.info(f"Password reset code sent for user '{username}'")
-                return code
-            else:
-                logger.error(f"Account service returned error: {response.status_code}")
-                return None
+        # Send code to account service for ALL managed projects
+        success_count = 0
+        failed_projects = []
         
-        except Exception as e:
-            logger.error(f"Failed to send reset code to account service: {e}")
+        for project in self.managed_projects:
+            try:
+                response = requests.post(
+                    f"{self.account_service_url}/api/v1/service/broker/send-reset-code",
+                    params={
+                        'projectId': project['project_id'],
+                        'code': code
+                    },
+                    headers={
+                        'X-API-Key': project['api_key']
+                    },
+                    timeout=10
+                )
+                
+                if response.status_code == 200:
+                    success_count += 1
+                    logger.info(f"Password reset code sent for project '{project['project_id']}'")
+                else:
+                    failed_projects.append(project['project_id'])
+                    logger.error(f"Account service error for project '{project['project_id']}': {response.status_code}")
+            
+            except Exception as e:
+                failed_projects.append(project['project_id'])
+                logger.error(f"Failed to send reset code to project '{project['project_id']}': {e}")
+        
+        # Return code if at least one project succeeded
+        if success_count > 0:
+            if failed_projects:
+                logger.warning(f"Reset code sent to {success_count}/{len(self.managed_projects)} projects. Failed: {', '.join(failed_projects)}")
+            else:
+                logger.info(f"Reset code successfully sent to all {success_count} managed projects")
+            return code
+        else:
+            logger.error("Failed to send reset code to any managed project")
             return None
     
     def _check_reset_rate_limit(self, username: str) -> bool:
@@ -385,6 +404,70 @@ class AuthManager:
             logger.info(f"Password reset completed for user '{username}'")
             return True
     
+    def fetch_project_aliases(self, project_ids: List[str]) -> Dict[str, Optional[str]]:
+        """
+        Fetch project aliases from account service.
+        
+        Args:
+            project_ids: List of project IDs to fetch aliases for
+            
+        Returns:
+            Dictionary mapping project_id -> alias (or None if not found)
+            Format: {'PRJ-123': 'Production', 'PRJ-456': 'Staging', 'PRJ-789': None}
+        """
+        if not project_ids:
+            return {}
+        
+        aliases = {}
+        
+        # Use first managed project's credentials for the API call
+        # (API key only needs to match one project in the array)
+        primary_project = self.managed_projects[0] if self.managed_projects else {
+            'project_id': self.project_id,
+            'api_key': self.api_key
+        }
+        
+        try:
+            response = requests.post(
+                f"{self.account_service_url}/api/v1/service/broker/project-aliases",
+                json={"projectIds": project_ids},
+                headers={
+                    'X-API-Key': primary_project['api_key'],
+                    'Content-Type': 'application/json'
+                },
+                timeout=10
+            )
+            
+            if response.status_code == 200:
+                data = response.json()
+                
+                # Parse response: {projects: {projectId: {alias, status}, ...}}
+                if 'projects' in data:
+                    projects_dict = data['projects']
+                    for project_id, project_info in projects_dict.items():
+                        status = project_info.get('status')
+                        
+                        if status == 'found':
+                            aliases[project_id] = project_info.get('alias')
+                        else:
+                            aliases[project_id] = None
+                            logger.debug(f"Project '{project_id}' alias not found (status: {status})")
+                
+                logger.info(f"Fetched aliases for {len(aliases)}/{len(project_ids)} projects")
+            else:
+                logger.error(f"Failed to fetch project aliases: HTTP {response.status_code}")
+                # Return None for all projects on error
+                for project_id in project_ids:
+                    aliases[project_id] = None
+        
+        except Exception as e:
+            logger.error(f"Error fetching project aliases: {e}")
+            # Return None for all projects on exception
+            for project_id in project_ids:
+                aliases[project_id] = None
+        
+        return aliases
+    
     def cleanup_expired_data(self):
         """Clean up expired sessions and reset codes."""
         with sqlite3.connect(self.db_path) as conn:
